@@ -11,13 +11,6 @@ import (
 	"slices"
 	"strings"
 
-	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
-
-	"gitlab.com/gitlab-org/cli/internal/commands/auth/authutils"
-
-	"gitlab.com/gitlab-org/cli/internal/iostreams"
-
-	"github.com/AlecAivazis/survey/v2"
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/charmbracelet/huh"
 	"github.com/spf13/cobra"
@@ -25,8 +18,11 @@ import (
 
 	"gitlab.com/gitlab-org/cli/internal/api"
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
+	"gitlab.com/gitlab-org/cli/internal/commands/auth/authutils"
 	"gitlab.com/gitlab-org/cli/internal/config"
 	"gitlab.com/gitlab-org/cli/internal/glinstance"
+	"gitlab.com/gitlab-org/cli/internal/iostreams"
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
 	"gitlab.com/gitlab-org/cli/internal/oauth2"
 )
 
@@ -261,44 +257,61 @@ func loginRun(ctx context.Context, opts *LoginOptions) error {
 			for _, host := range detectedHosts {
 				options = append(options, host.String())
 			}
-			options = append(options, "Enter a different hostname")
+			options = append(options, promptLoginDifferentHostname)
 
-			var selectedIndex int
-			err := survey.AskOne(&survey.Select{
-				Message: "Found GitLab instances in git remotes. Select one:",
-				Options: options,
-			}, &selectedIndex)
+			var selectedOption string
+			err := opts.IO.Select(ctx, &selectedOption, "Found GitLab instances in git remotes. Select one:", options)
 			if err != nil {
 				return fmt.Errorf("could not prompt: %w", err)
 			}
 
-			// Check if user selected "Enter a different hostname" (last option)
-			if selectedIndex == len(options)-1 {
+			// Check if user selected "Enter a different hostname"
+			if selectedOption == promptLoginDifferentHostname {
 				// Fall back to manual entry
 				hostname = opts.defaultHostname
 				apiHostname = hostname
-				err := survey.AskOne(&survey.Input{
-					Message: "GitLab hostname:",
-				}, &hostname, survey.WithValidator(hostnameValidator))
+
+				hostnameInput := huh.NewInput().
+					Title("GitLab hostname:").
+					Value(&hostname).
+					Placeholder(opts.defaultHostname).
+					Validate(func(s string) error {
+						return hostnameValidator(s)
+					})
+				err := opts.IO.Run(ctx, hostnameInput)
 				if err != nil {
 					return fmt.Errorf("could not prompt: %w", err)
 				}
-				err = survey.AskOne(&survey.Input{
-					Message: "API hostname:",
-					Help:    "For instances with a different hostname for the API endpoint.",
-					Default: hostname,
-				}, &apiHostname, survey.WithValidator(hostnameValidator))
+
+				// Set default for API hostname
+				if apiHostname == opts.defaultHostname {
+					apiHostname = hostname
+				}
+
+				apiHostnameInput := huh.NewInput().
+					Title("API hostname:").
+					Description("For instances with a different hostname for the API endpoint.").
+					Value(&apiHostname).
+					Placeholder(hostname).
+					Validate(func(s string) error {
+						return hostnameValidator(s)
+					})
+				err = opts.IO.Run(ctx, apiHostnameInput)
 				if err != nil {
 					return fmt.Errorf("could not prompt: %w", err)
 				}
 			} else {
-				// User selected a detected host by index
-				hostname = detectedHosts[selectedIndex].hostname
-				apiHostname = hostname
+				// User selected a detected host - find it in the list
+				for _, host := range detectedHosts {
+					if host.String() == selectedOption {
+						hostname = host.hostname
+						apiHostname = hostname
+						break
+					}
+				}
 			}
 		} else {
 			// No detected hosts or detection failed, fall back to original behavior
-			var hostType int
 			options := []string{}
 			if hosts, err := cfg.Hosts(); err == nil {
 				options = append(options, hosts...)
@@ -306,37 +319,51 @@ func loginRun(ctx context.Context, opts *LoginOptions) error {
 			if !slices.Contains(options, opts.defaultHostname) {
 				options = append(options, opts.defaultHostname)
 			}
-			options = append(options, "GitLab Self-Managed or GitLab Dedicated instance")
+			options = append(options, promptSelfManagedOrDedicatedInstance)
 
-			err := survey.AskOne(&survey.Select{
-				Message: "What GitLab instance do you want to sign in to?",
-				Options: options,
-			}, &hostType)
+			var selectedOption string
+			err := opts.IO.Select(ctx, &selectedOption, "What GitLab instance do you want to sign in to?", options)
 			if err != nil {
 				return fmt.Errorf("could not prompt: %w", err)
 			}
 
-			isSelfHosted = hostType == len(options)-1
+			isSelfHosted = selectedOption == promptSelfManagedOrDedicatedInstance
 
 			if isSelfHosted {
 				hostname = opts.defaultHostname
 				apiHostname = hostname
-				err := survey.AskOne(&survey.Input{
-					Message: "GitLab hostname:",
-				}, &hostname, survey.WithValidator(hostnameValidator))
+
+				hostnameInput := huh.NewInput().
+					Title("GitLab hostname:").
+					Value(&hostname).
+					Placeholder(opts.defaultHostname).
+					Validate(func(s string) error {
+						return hostnameValidator(s)
+					})
+				err := opts.IO.Run(ctx, hostnameInput)
 				if err != nil {
 					return fmt.Errorf("could not prompt: %w", err)
 				}
-				err = survey.AskOne(&survey.Input{
-					Message: "API hostname:",
-					Help:    "For instances with a different hostname for the API endpoint.",
-					Default: hostname,
-				}, &apiHostname, survey.WithValidator(hostnameValidator))
+
+				// Set default for API hostname
+				if apiHostname == opts.defaultHostname {
+					apiHostname = hostname
+				}
+
+				apiHostnameInput := huh.NewInput().
+					Title("API hostname:").
+					Description("For instances with a different hostname for the API endpoint.").
+					Value(&apiHostname).
+					Placeholder(hostname).
+					Validate(func(s string) error {
+						return hostnameValidator(s)
+					})
+				err = opts.IO.Run(ctx, apiHostnameInput)
 				if err != nil {
 					return fmt.Errorf("could not prompt: %w", err)
 				}
 			} else {
-				hostname = options[hostType]
+				hostname = selectedOption
 				apiHostname = hostname
 			}
 		}
@@ -384,21 +411,18 @@ func loginRun(ctx context.Context, opts *LoginOptions) error {
 	)
 
 	if opts.Interactive {
-		err := survey.AskOne(&survey.Select{
-			Message: "How would you like to sign in?",
-			Options: []string{
-				"Token",
-				"Web",
-			},
-		}, &loginType)
+		loginTypeOptions := []string{promptLoginTypeToken, promptLoginTypeWeb}
+		err := opts.IO.Select(ctx, &loginType, "How would you like to sign in?", loginTypeOptions)
 		if err != nil {
 			return fmt.Errorf("could not get sign-in type: %w", err)
 		}
 
-		err = survey.AskOne(&survey.Input{
-			Message: "What domains does this host use for the container registry and image dependency proxy?",
-			Default: defaultContainerRegistryDomainsString(hostname),
-		}, &containerRegistryDomains)
+		containerRegistryDomains = defaultContainerRegistryDomainsString(hostname)
+		containerRegistryInput := huh.NewInput().
+			Title("What domains does this host use for the container registry and image dependency proxy?").
+			Value(&containerRegistryDomains).
+			Placeholder(defaultContainerRegistryDomainsString(hostname))
+		err = opts.IO.Run(ctx, containerRegistryInput)
 		if err != nil {
 			return fmt.Errorf("could not get container registry domains: %w", err)
 		}
@@ -406,8 +430,8 @@ func loginRun(ctx context.Context, opts *LoginOptions) error {
 
 	var token string
 	var err error
-	if strings.EqualFold(loginType, "token") {
-		token, err = showTokenPrompt(opts.IO, hostname)
+	if strings.EqualFold(loginType, promptLoginTypeToken) {
+		token, err = showTokenPrompt(ctx, opts.IO, hostname)
 		if err != nil {
 			return err
 		}
@@ -459,15 +483,9 @@ func loginRun(ctx context.Context, opts *LoginOptions) error {
 	credentialFlow := &authutils.GitCredentialFlow{Executable: glabExecutable}
 
 	if opts.Interactive {
-		err = survey.AskOne(&survey.Select{
-			Message: "Choose default Git protocol:",
-			Options: []string{
-				"SSH",
-				"HTTPS",
-				"HTTP",
-			},
-			Default: "HTTPS",
-		}, &gitProtocol)
+		gitProtocolOptions := []string{promptProtocolSSH, promptProtocolHTTPS, promptProtocolHTTP}
+		gitProtocol = promptProtocolHTTPS // Set default
+		err = opts.IO.Select(ctx, &gitProtocol, "Choose default Git protocol:", gitProtocolOptions)
 		if err != nil {
 			return fmt.Errorf("could not prompt: %w", err)
 		}
@@ -480,14 +498,9 @@ func loginRun(ctx context.Context, opts *LoginOptions) error {
 		}
 
 		if isSelfHosted {
-			err = survey.AskOne(&survey.Select{
-				Message: "Choose host API protocol:",
-				Options: []string{
-					"HTTPS",
-					"HTTP",
-				},
-				Default: "HTTPS",
-			}, &apiProtocol)
+			apiProtocolOptions := []string{promptProtocolHTTPS, promptProtocolHTTP}
+			apiProtocol = promptProtocolHTTPS // Set default
+			err = opts.IO.Select(ctx, &apiProtocol, "Choose host API protocol:", apiProtocolOptions)
 			if err != nil {
 				return fmt.Errorf("could not prompt: %w", err)
 			}
@@ -574,14 +587,22 @@ func getAccessTokenTip(hostname string) string {
 	The minimum required scopes are 'api' and 'write_repository'.`, hostname)
 }
 
-func showTokenPrompt(io *iostreams.IOStreams, hostname string) (string, error) {
+func showTokenPrompt(ctx context.Context, io *iostreams.IOStreams, hostname string) (string, error) {
 	fmt.Fprintln(io.StdErr)
 	fmt.Fprintln(io.StdErr, heredoc.Doc(getAccessTokenTip(hostname)))
 
 	var token string
-	err := survey.AskOne(&survey.Password{
-		Message: "Paste your authentication token:",
-	}, &token, survey.WithValidator(survey.Required))
+	tokenInput := huh.NewInput().
+		Title("Paste your authentication token:").
+		Value(&token).
+		EchoMode(huh.EchoModePassword).
+		Validate(func(s string) error {
+			if s == "" {
+				return fmt.Errorf("required")
+			}
+			return nil
+		})
+	err := io.Run(ctx, tokenInput)
 	if err != nil {
 		return "", fmt.Errorf("could not prompt: %w", err)
 	}
