@@ -10,8 +10,18 @@ import (
 	"runtime/debug"
 	"strings"
 	"time"
+	"unicode/utf8"
 
-	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
+	"github.com/MakeNowJust/heredoc/v2"
+	"github.com/gdamore/tcell/v2"
+	"github.com/lunixbochs/vtclean"
+	"github.com/pkg/errors"
+	"github.com/rivo/tview"
+	"github.com/spf13/cobra"
+	"golang.org/x/text/cases"
+	"golang.org/x/text/language"
+
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 
 	"gitlab.com/gitlab-org/cli/internal/api"
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
@@ -20,18 +30,8 @@ import (
 	"gitlab.com/gitlab-org/cli/internal/git"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/internal/iostreams"
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
 	"gitlab.com/gitlab-org/cli/internal/utils"
-
-	"github.com/MakeNowJust/heredoc/v2"
-	"github.com/gdamore/tcell/v2"
-	"github.com/lunixbochs/vtclean"
-	"github.com/pkg/errors"
-	"github.com/rivo/tview"
-	"github.com/spf13/cobra"
-	gitlab "gitlab.com/gitlab-org/api/client-go"
-
-	"golang.org/x/text/cases"
-	"golang.org/x/text/language"
 )
 
 type options struct {
@@ -42,7 +42,7 @@ type options struct {
 
 	refName       string
 	openInBrowser bool
-	pipelineID    int
+	pipelineID    int64
 }
 
 type ViewJobKind int64
@@ -53,7 +53,7 @@ const (
 )
 
 type ViewJob struct {
-	ID           int        `json:"id"`
+	ID           int64      `json:"id"`
 	Name         string     `json:"name"`
 	StartedAt    *time.Time `json:"started_at"`
 	FinishedAt   *time.Time `json:"finished_at"`
@@ -155,7 +155,7 @@ func NewCmdView(f cmdutils.Factory) *cobra.Command {
 	pipelineCIView.Flags().
 		StringVarP(&opts.refName, "branch", "b", "", "Check pipeline status for a branch or tag. Defaults to the current branch.")
 	pipelineCIView.Flags().BoolVarP(&opts.openInBrowser, "web", "w", false, "Open pipeline in a browser. Uses default browser, or browser specified in BROWSER variable.")
-	pipelineCIView.Flags().IntVarP(&opts.pipelineID, "pipelineid", "p", 0, "Check pipeline status for a specific pipeline ID.")
+	pipelineCIView.Flags().Int64VarP(&opts.pipelineID, "pipelineid", "p", 0, "Check pipeline status for a specific pipeline ID.")
 	pipelineCIView.MarkFlagsMutuallyExclusive("branch", "pipelineid")
 
 	return pipelineCIView
@@ -189,7 +189,7 @@ func (o *options) run() error {
 	}
 
 	projectID := repo.FullName()
-	var pipelineID int
+	var pipelineID int64
 	var webURL string
 	var pipelineCreatedAt time.Time
 	var commit *gitlab.Commit
@@ -210,19 +210,22 @@ func (o *options) run() error {
 			return err
 		}
 	} else {
-		commit, _, err = client.Commits.GetCommit(projectID, o.refName, nil)
+		// Get pipeline by branch reference (not by commit's LastPipeline)
+		pipeline, err := ciutils.GetPipelineWithFallback(client, projectID, o.refName, o.io)
 		if err != nil {
 			return err
 		}
 
-		if commit.LastPipeline == nil {
-			return fmt.Errorf("Can't find pipeline for commit: %s", commit.ID)
-		}
+		pipelineID = pipeline.ID
+		webURL = pipeline.WebURL
+		pipelineCreatedAt = *pipeline.CreatedAt
+		commitSHA = pipeline.SHA
 
-		pipelineID = commit.LastPipeline.ID
-		webURL = commit.LastPipeline.WebURL
-		pipelineCreatedAt = *commit.LastPipeline.CreatedAt
-		commitSHA = commit.ID
+		// Get commit details for display purposes
+		commit, _, err = client.Commits.GetCommit(projectID, commitSHA, nil)
+		if err != nil {
+			return err
+		}
 	}
 
 	if o.openInBrowser { // open in browser if --web flag is specified
@@ -950,7 +953,8 @@ func link(
 	// Drawing a job in the same stage
 	// left of view
 	if !firstStage {
-		if r, _, _, _ := screen.GetContent(x2-p, y1+h/2); r == '╚' {
+		s, _, _ := screen.Get(x2-p, y1+h/2)
+		if r, _ := utf8.DecodeRuneInString(s); r == '╚' {
 			screen.SetContent(x2-p, y1+h/2, '╠', nil, tcell.StyleDefault)
 		} else {
 			screen.SetContent(x2-p, y1+h/2, '╦', nil, tcell.StyleDefault)
@@ -965,7 +969,8 @@ func link(
 	}
 	// right of view
 	if !lastStage {
-		if r, _, _, _ := screen.GetContent(x2+w+p-1, y1+h/2); r == '┛' {
+		s, _, _ := screen.Get(x2+w+p-1, y1+h/2)
+		if r, _ := utf8.DecodeRuneInString(s); r == '┛' {
 			screen.SetContent(x2+w+p-1, y1+h/2, '╣', nil, tcell.StyleDefault)
 		}
 		for i := range p - 1 {
