@@ -77,7 +77,7 @@ func TestAgentBootstrap_HappyPath_AgentNotRegisteredYet(t *testing.T) {
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(nil),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Flux Helm Resources ... ")),
 		fluxWrapper.EXPECT().createHelmRepositoryManifest().Return(helmRepositoryFile, nil),
@@ -142,7 +142,7 @@ func TestAgentBootstrap_HappyPath_AgentAlreadyRegistered(t *testing.T) {
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(nil),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Flux Helm Resources ... ")),
 		fluxWrapper.EXPECT().createHelmRepositoryManifest().Return(helmRepositoryFile, nil),
@@ -202,7 +202,7 @@ func TestAgentBootstrap_HappyPath_NoEnvironmentCreation(t *testing.T) {
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(nil),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Flux Helm Resources ... ")),
 		fluxWrapper.EXPECT().createHelmRepositoryManifest().Return(helmRepositoryFile, nil),
@@ -266,7 +266,7 @@ func TestAgentBootstrap_HappyPath_CustomEnvironmentValues(t *testing.T) {
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(nil),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Flux Helm Resources ... ")),
 		fluxWrapper.EXPECT().createHelmRepositoryManifest().Return(helmRepositoryFile, nil),
@@ -336,7 +336,7 @@ func TestAgentBootstrap_HappyPath_NoReconcile(t *testing.T) {
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(nil),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Flux Helm Resources ... ")),
 		fluxWrapper.EXPECT().createHelmRepositoryManifest().Return(helmRepositoryFile, nil),
@@ -399,7 +399,7 @@ func TestAgentBootstrap_HappyPath_CustomFluxHelmManifestFileNames(t *testing.T)
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(nil),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Flux Helm Resources ... ")),
 		fluxWrapper.EXPECT().createHelmRepositoryManifest().Return(helmRepositoryFile, nil),
@@ -622,7 +622,7 @@ func TestAgentBootstrap_Error_createAgentTokenSecret(t *testing.T) {
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(actualErr),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(actualErr),
 		stderr.EXPECT().Write([]byte("[FAILED]\n")),
 		stderr.EXPECT().Write(ContainsBytes([]byte(actualErr.Error()))),
 	)
@@ -672,7 +672,7 @@ func TestAgentBootstrap_Error_createHelmRepositoryManifest(t *testing.T) {
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(nil),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Flux Helm Resources ... ")),
 		fluxWrapper.EXPECT().createHelmRepositoryManifest().Return(file{}, actualErr),
@@ -728,7 +728,7 @@ func TestAgentBootstrap_Error_SyncFile_HelmRepositoryFile(t *testing.T) {
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(nil),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Flux Helm Resources ... ")),
 		fluxWrapper.EXPECT().createHelmRepositoryManifest().Return(helmRepositoryFile, nil),
@@ -789,7 +789,7 @@ func TestAgentBootstrap_Error_SyncFile_HelmReleaseFile(t *testing.T) {
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(nil),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Flux Helm Resources ... ")),
 		fluxWrapper.EXPECT().createHelmRepositoryManifest().Return(helmRepositoryFile, nil),
@@ -851,7 +851,7 @@ func TestAgentBootstrap_Error_reconcile(t *testing.T) {
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(nil),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Flux Helm Resources ... ")),
 		fluxWrapper.EXPECT().createHelmRepositoryManifest().Return(helmRepositoryFile, nil),
@@ -908,7 +908,7 @@ func TestAgentBootstrap_HappyPath_WithoutFlux(t *testing.T) {
 		api.EXPECT().CreateAgentToken(agent.ID).Return(agentToken, nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Kubernetes Secret with Agent Token ... ")),
-		kubectlWrapper.EXPECT().createAgentTokenSecret(42, agentTokenValue).Return(nil),
+		kubectlWrapper.EXPECT().createAgentTokenSecret(int64(42), agentTokenValue).Return(nil),
 		stderr.EXPECT().Write([]byte("[OK]\n")),
 		stderr.EXPECT().Write([]byte("Creating Flux Helm Resources ... ")),
 		fluxWrapper.EXPECT().createHelmRepositoryManifest().Return(helmRepositoryFile, nil),
