@@ -6,19 +6,19 @@ import (
 	"strconv"
 	"strings"
 
-	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
-
-	"gitlab.com/gitlab-org/cli/internal/iostreams"
-
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
+
 	gitlab "gitlab.com/gitlab-org/api/client-go"
+
 	"gitlab.com/gitlab-org/cli/internal/api"
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/dbg"
 	"gitlab.com/gitlab-org/cli/internal/git"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
+	"gitlab.com/gitlab-org/cli/internal/iostreams"
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
 )
 
 type options struct {
@@ -202,10 +202,10 @@ func groupClone(opts *options, ctxOpts *ContextOpts) error {
 		listOpts.PerPage = 30
 	}
 	if opts.perPage != 0 {
-		listOpts.PerPage = opts.perPage
+		listOpts.PerPage = int64(opts.perPage)
 	}
 	if opts.page != 0 {
-		listOpts.Page = opts.page
+		listOpts.Page = int64(opts.page)
 	}
 
 	var projects []*gitlab.Project
